PRINT ''
GO
PRINT '*** Creating DDL Trigger for Database'
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE TABLE [dbo].[DatabaseLog] (
    [DatabaseLogID] INT            IDENTITY (1, 1) NOT NULL,
    [PostTime]      DATETIME       NOT NULL,
    [DatabaseUser]  [sysname]      NOT NULL,
    [Event]         [sysname]      NOT NULL,
    [Schema]        [sysname]      NULL,
    [Object]        [sysname]      NULL,
    [TSQL]          NVARCHAR (MAX) NOT NULL,
    [XmlEvent]      XML            NOT NULL
)
GO
PRINT ''
GO
PRINT '*** Creating Tables'
GO
CREATE TABLE [dbo].[AdventureWorksDWBuildVersion] (
    [DBVersion]   NVARCHAR (50) NOT NULL,
    [VersionDate] DATETIME      NOT NULL
)
GO
CREATE TABLE [dbo].[DimAccount] (
    [AccountKey]                    INT            IDENTITY (1, 1) NOT NULL,
    [ParentAccountKey]              INT            NULL,
    [AccountCodeAlternateKey]       INT            NULL,
    [ParentAccountCodeAlternateKey] INT            NULL,
    [AccountDescription]            NVARCHAR (50)  NULL,
    [AccountType]                   NVARCHAR (50)  NULL,
    [Operator]                      NVARCHAR (50)  NULL,
    [CustomMembers]                 NVARCHAR (300) NULL,
    [ValueType]                     NVARCHAR (50)  NULL,
    [CustomMemberOptions]           NVARCHAR (200) NULL
)
GO
CREATE TABLE [dbo].[DimCurrency] (
    [CurrencyKey]          INT           IDENTITY (1, 1) NOT NULL,
    [CurrencyAlternateKey] NCHAR (3)     NOT NULL,
    [CurrencyName]         NVARCHAR (50) NOT NULL
)
GO
CREATE TABLE [dbo].[DimCustomer] (
    [CustomerKey]          INT            IDENTITY (1, 1) NOT NULL,
    [GeographyKey]         INT            NULL,
    [CustomerAlternateKey] NVARCHAR (15)  NOT NULL,
    [Title]                NVARCHAR (8)   NULL,
    [FirstName]            NVARCHAR (50)  NULL,
    [MiddleName]           NVARCHAR (50)  NULL,
    [LastName]             NVARCHAR (50)  NULL,
    [NameStyle]            BIT            NULL,
    [BirthDate]            DATE           NULL,
    [MaritalStatus]        NCHAR (1)      NULL,
    [Suffix]               NVARCHAR (10)  NULL,
    [Gender]               NVARCHAR (1)   NULL,
    [EmailAddress]         NVARCHAR (50)  NULL,
    [YearlyIncome]         MONEY          NULL,
    [TotalChildren]        TINYINT        NULL,
    [NumberChildrenAtHome] TINYINT        NULL,
    [EnglishEducation]     NVARCHAR (40)  NULL,
    [SpanishEducation]     NVARCHAR (40)  NULL,
    [FrenchEducation]      NVARCHAR (40)  NULL,
    [EnglishOccupation]    NVARCHAR (100) NULL,
    [SpanishOccupation]    NVARCHAR (100) NULL,
    [FrenchOccupation]     NVARCHAR (100) NULL,
    [HouseOwnerFlag]       NCHAR (1)      NULL,
    [NumberCarsOwned]      TINYINT        NULL,
    [AddressLine1]         NVARCHAR (120) NULL,
    [AddressLine2]         NVARCHAR (120) NULL,
    [Phone]                NVARCHAR (20)  NULL,
    [DateFirstPurchase]    DATE           NULL,
    [CommuteDistance]      NVARCHAR (15)  NULL
)
GO
CREATE TABLE [dbo].[DimDate] (
    [DateKey]              INT           NOT NULL,
    [FullDateAlternateKey] DATE          NOT NULL,
    [DayNumberOfWeek]      TINYINT       NOT NULL,
    [EnglishDayNameOfWeek] NVARCHAR (10) NOT NULL,
    [SpanishDayNameOfWeek] NVARCHAR (10) NOT NULL,
    [FrenchDayNameOfWeek]  NVARCHAR (10) NOT NULL,
    [DayNumberOfMonth]     TINYINT       NOT NULL,
    [DayNumberOfYear]      SMALLINT      NOT NULL,
    [WeekNumberOfYear]     TINYINT       NOT NULL,
    [EnglishMonthName]     NVARCHAR (10) NOT NULL,
    [SpanishMonthName]     NVARCHAR (10) NOT NULL,
    [FrenchMonthName]      NVARCHAR (10) NOT NULL,
    [MonthNumberOfYear]    TINYINT       NOT NULL,
    [CalendarQuarter]      TINYINT       NOT NULL,
    [CalendarYear]         SMALLINT      NOT NULL,
    [CalendarSemester]     TINYINT       NOT NULL,
    [FiscalQuarter]        TINYINT       NOT NULL,
    [FiscalYear]           SMALLINT      NOT NULL,
    [FiscalSemester]       TINYINT       NOT NULL
)
GO
CREATE TABLE [dbo].[DimDepartmentGroup] (
    [DepartmentGroupKey]       INT           IDENTITY (1, 1) NOT NULL,
    [ParentDepartmentGroupKey] INT           NULL,
    [DepartmentGroupName]      NVARCHAR (50) NULL
)
GO
CREATE TABLE [dbo].[DimEmployee] (
    [EmployeeKey]                          INT            IDENTITY (1, 1) NOT NULL,
    [ParentEmployeeKey]                    INT            NULL,
    [EmployeeNationalIDAlternateKey]       NVARCHAR (15)  NULL,
    [ParentEmployeeNationalIDAlternateKey] NVARCHAR (15)  NULL,
    [SalesTerritoryKey]                    INT            NULL,
    [FirstName]                            NVARCHAR (50)  NOT NULL,
    [LastName]                             NVARCHAR (50)  NOT NULL,
    [MiddleName]                           NVARCHAR (50)  NULL,
    [NameStyle]                            BIT            NOT NULL,
    [Title]                                NVARCHAR (50)  NULL,
    [HireDate]                             DATE           NULL,
    [BirthDate]                            DATE           NULL,
    [LoginID]                              NVARCHAR (256) NULL,
    [EmailAddress]                         NVARCHAR (50)  NULL,
    [Phone]                                NVARCHAR (25)  NULL,
    [MaritalStatus]                        NCHAR (1)      NULL,
    [EmergencyContactName]                 NVARCHAR (50)  NULL,
    [EmergencyContactPhone]                NVARCHAR (25)  NULL,
    [SalariedFlag]                         BIT            NULL,
    [Gender]                               NCHAR (1)      NULL,
    [PayFrequency]                         TINYINT        NULL,
    [BaseRate]                             MONEY          NULL,
    [VacationHours]                        SMALLINT       NULL,
    [SickLeaveHours]                       SMALLINT       NULL,
    [CurrentFlag]                          BIT            NOT NULL,
    [SalesPersonFlag]                      BIT            NOT NULL,
    [DepartmentName]                       NVARCHAR (50)  NULL,
    [StartDate]                            DATE           NULL,
    [EndDate]                              DATE           NULL,
    [Status]                               NVARCHAR (50)  NULL
)
GO
CREATE TABLE [dbo].[DimGeography] (
    [GeographyKey]             INT           IDENTITY (1, 1) NOT NULL,
    [City]                     NVARCHAR (30) NULL,
    [StateProvinceCode]        NVARCHAR (3)  NULL,
    [StateProvinceName]        NVARCHAR (50) NULL,
    [CountryRegionCode]        NVARCHAR (3)  NULL,
    [EnglishCountryRegionName] NVARCHAR (50) NULL,
    [SpanishCountryRegionName] NVARCHAR (50) NULL,
    [FrenchCountryRegionName]  NVARCHAR (50) NULL,
    [PostalCode]               NVARCHAR (15) NULL,
    [SalesTerritoryKey]        INT           NULL
)
GO
CREATE TABLE [dbo].[DimOrganization] (
    [OrganizationKey]       INT           IDENTITY (1, 1) NOT NULL,
    [ParentOrganizationKey] INT           NULL,
    [PercentageOfOwnership] NVARCHAR (16) NULL,
    [OrganizationName]      NVARCHAR (50) NULL,
    [CurrencyKey]           INT           NULL
)
GO
CREATE TABLE [dbo].[DimProduct] (
    [ProductKey]            INT             IDENTITY (1, 1) NOT NULL,
    [ProductAlternateKey]   NVARCHAR (25)   NULL,
    [ProductSubcategoryKey] INT             NULL,
    [WeightUnitMeasureCode] NCHAR (3)       NULL,
    [SizeUnitMeasureCode]   NCHAR (3)       NULL,
    [EnglishProductName]    NVARCHAR (50)   NOT NULL,
    [SpanishProductName]    NVARCHAR (50)   NOT NULL,
    [FrenchProductName]     NVARCHAR (50)   NOT NULL,
    [StandardCost]          MONEY           NULL,
    [FinishedGoodsFlag]     BIT             NOT NULL,
    [Color]                 NVARCHAR (15)   NOT NULL,
    [SafetyStockLevel]      SMALLINT        NULL,
    [ReorderPoint]          SMALLINT        NULL,
    [ListPrice]             MONEY           NULL,
    [Size]                  NVARCHAR (50)   NULL,
    [SizeRange]             NVARCHAR (50)   NULL,
    [Weight]                FLOAT           NULL,
    [DaysToManufacture]     INT             NULL,
    [ProductLine]           NCHAR (2)       NULL,
    [DealerPrice]           MONEY           NULL,
    [Class]                 NCHAR (2)       NULL,
    [Style]                 NCHAR (2)       NULL,
    [ModelName]             NVARCHAR (50)   NULL,
    [LargePhoto]            VARBINARY (MAX) NULL,
    [EnglishDescription]    NVARCHAR (400)  NULL,
    [FrenchDescription]     NVARCHAR (400)  COLLATE French_CI_AS NULL,
    [ChineseDescription]    NVARCHAR (400)  COLLATE Chinese_PRC_CI_AI NULL,
    [ArabicDescription]     NVARCHAR (400)  COLLATE Arabic_CI_AS NULL,
    [HebrewDescription]     NVARCHAR (400)  COLLATE Hebrew_CI_AS NULL,
    [ThaiDescription]       NVARCHAR (400)  COLLATE Thai_CI_AS NULL,
    [GermanDescription]     NVARCHAR (400)  COLLATE Latin1_General_100_CI_AS NULL,
    [JapaneseDescription]   NVARCHAR (400)  COLLATE Japanese_CI_AS NULL,
    [TurkishDescription]    NVARCHAR (400)  COLLATE Turkish_CI_AS NULL,
    [StartDate]             DATETIME        NULL,
    [EndDate]               DATETIME        NULL,
    [Status]                NVARCHAR (7)    NULL
)
GO
CREATE TABLE [dbo].[DimProductCategory] (
    [ProductCategoryKey]          INT           IDENTITY (1, 1) NOT NULL,
    [ProductCategoryAlternateKey] INT           NULL,
    [EnglishProductCategoryName]  NVARCHAR (50) NOT NULL,
    [SpanishProductCategoryName]  NVARCHAR (50) NOT NULL,
    [FrenchProductCategoryName]   NVARCHAR (50) NOT NULL
)
GO
CREATE TABLE [dbo].[DimProductSubcategory] (
    [ProductSubcategoryKey]          INT           IDENTITY (1, 1) NOT NULL,
    [ProductSubcategoryAlternateKey] INT           NULL,
    [EnglishProductSubcategoryName]  NVARCHAR (50) NOT NULL,
    [SpanishProductSubcategoryName]  NVARCHAR (50) NOT NULL,
    [FrenchProductSubcategoryName]   NVARCHAR (50) NOT NULL,
    [ProductCategoryKey]             INT           NULL
)
GO
CREATE TABLE [dbo].[DimPromotion] (
    [PromotionKey]             INT            IDENTITY (1, 1) NOT NULL,
    [PromotionAlternateKey]    INT            NULL,
    [EnglishPromotionName]     NVARCHAR (255) NULL,
    [SpanishPromotionName]     NVARCHAR (255) NULL,
    [FrenchPromotionName]      NVARCHAR (255) NULL,
    [DiscountPct]              FLOAT          NULL,
    [EnglishPromotionType]     NVARCHAR (50)  NULL,
    [SpanishPromotionType]     NVARCHAR (50)  NULL,
    [FrenchPromotionType]      NVARCHAR (50)  NULL,
    [EnglishPromotionCategory] NVARCHAR (50)  NULL,
    [SpanishPromotionCategory] NVARCHAR (50)  NULL,
    [FrenchPromotionCategory]  NVARCHAR (50)  NULL,
    [StartDate]                DATETIME       NOT NULL,
    [EndDate]                  DATETIME       NULL,
    [MinQty]                   INT            NULL,
    [MaxQty]                   INT            NULL
)
GO
CREATE TABLE [dbo].[DimReseller] (
    [ResellerKey]          INT           IDENTITY (1, 1) NOT NULL,
    [GeographyKey]         INT           NULL,
    [ResellerAlternateKey] NVARCHAR (15) NULL,
    [Phone]                NVARCHAR (25) NULL,
    [BusinessType]         VARCHAR (20)  NOT NULL,
    [ResellerName]         NVARCHAR (50) NOT NULL,
    [NumberEmployees]      INT           NULL,
    [OrderFrequency]       CHAR (1)      NULL,
    [OrderMonth]           TINYINT       NULL,
    [FirstOrderYear]       INT           NULL,
    [LastOrderYear]        INT           NULL,
    [ProductLine]          NVARCHAR (50) NULL,
    [AddressLine1]         NVARCHAR (60) NULL,
    [AddressLine2]         NVARCHAR (60) NULL,
    [AnnualSales]          MONEY         NULL,
    [BankName]             NVARCHAR (50) NULL,
    [MinPaymentType]       TINYINT       NULL,
    [MinPaymentAmount]     MONEY         NULL,
    [AnnualRevenue]        MONEY         NULL,
    [YearOpened]           INT           NULL
)
GO
CREATE TABLE [dbo].[DimSalesReason] (
    [SalesReasonKey]          INT           IDENTITY (1, 1) NOT NULL,
    [SalesReasonAlternateKey] INT           NOT NULL,
    [SalesReasonName]         NVARCHAR (50) NOT NULL,
    [SalesReasonReasonType]   NVARCHAR (50) NOT NULL
)
GO
CREATE TABLE [dbo].[DimSalesTerritory] (
    [SalesTerritoryKey]          INT           IDENTITY (1, 1) NOT NULL,
    [SalesTerritoryAlternateKey] INT           NULL,
    [SalesTerritoryRegion]       NVARCHAR (50) NOT NULL,
    [SalesTerritoryCountry]      NVARCHAR (50) NOT NULL,
    [SalesTerritoryGroup]        NVARCHAR (50) NULL
)
GO
CREATE TABLE [dbo].[DimScenario] (
    [ScenarioKey]  INT           IDENTITY (1, 1) NOT NULL,
    [ScenarioName] NVARCHAR (50) NULL
)
GO
CREATE TABLE [dbo].[FactAdditionalInternationalProductDescription] (
    [ProductKey]         INT            NOT NULL,
    [CultureName]        NVARCHAR (50)  NOT NULL,
    [ProductDescription] NVARCHAR (MAX) NOT NULL
)
GO
CREATE TABLE [dbo].[FactCallCenter] (
    [FactCallCenterID]    INT           IDENTITY (1, 1) NOT NULL,
    [DateKey]             INT           NOT NULL,
    [WageType]            NVARCHAR (15) NOT NULL,
    [Shift]               NVARCHAR (20) NOT NULL,
    [LevelOneOperators]   SMALLINT      NOT NULL,
    [LevelTwoOperators]   SMALLINT      NOT NULL,
    [TotalOperators]      SMALLINT      NOT NULL,
    [Calls]               INT           NOT NULL,
    [AutomaticResponses]  INT           NOT NULL,
    [Orders]              INT           NOT NULL,
    [IssuesRaised]        SMALLINT      NOT NULL,
    [AverageTimePerIssue] SMALLINT      NOT NULL,
    [ServiceGrade]        FLOAT         NOT NULL
)
GO
CREATE TABLE [dbo].[FactCurrencyRate] (
    [CurrencyKey]  INT   NOT NULL,
    [DateKey]      INT   NOT NULL,
    [AverageRate]  FLOAT NOT NULL,
    [EndOfDayRate] FLOAT NOT NULL
)
GO
CREATE TABLE [dbo].[FactFinance] (
    [FinanceKey]         INT   IDENTITY (1, 1) NOT NULL,
    [DateKey]            INT   NOT NULL,
    [OrganizationKey]    INT   NOT NULL,
    [DepartmentGroupKey] INT   NOT NULL,
    [ScenarioKey]        INT   NOT NULL,
    [AccountKey]         INT   NOT NULL,
    [Amount]             FLOAT NOT NULL
)
GO
CREATE TABLE [dbo].[FactInternetSales] (
    [ProductKey]            INT           NOT NULL,
    [OrderDateKey]          INT           NOT NULL,
    [DueDateKey]            INT           NOT NULL,
    [ShipDateKey]           INT           NOT NULL,
    [CustomerKey]           INT           NOT NULL,
    [PromotionKey]          INT           NOT NULL,
    [CurrencyKey]           INT           NOT NULL,
    [SalesTerritoryKey]     INT           NOT NULL,
    [SalesOrderNumber]      NVARCHAR (20) NOT NULL,
    [SalesOrderLineNumber]  TINYINT       NOT NULL,
    [RevisionNumber]        TINYINT       NOT NULL,
    [OrderQuantity]         SMALLINT      NOT NULL,
    [UnitPrice]             MONEY         NOT NULL,
    [ExtendedAmount]        MONEY         NOT NULL,
    [UnitPriceDiscountPct]  FLOAT         NOT NULL,
    [DiscountAmount]        FLOAT         NOT NULL,
    [ProductStandardCost]   MONEY         NOT NULL,
    [TotalProductCost]      MONEY         NOT NULL,
    [SalesAmount]           MONEY         NOT NULL,
    [TaxAmt]                MONEY         NOT NULL,
    [Freight]               MONEY         NOT NULL,
    [CarrierTrackingNumber] NVARCHAR (25) NULL,
    [CustomerPONumber]      NVARCHAR (25) NULL
)
GO
CREATE TABLE [dbo].[FactResellerSales] (
    [ProductKey]            INT           NOT NULL,
    [OrderDateKey]          INT           NOT NULL,
    [DueDateKey]            INT           NOT NULL,
    [ShipDateKey]           INT           NOT NULL,
    [ResellerKey]           INT           NOT NULL,
    [EmployeeKey]           INT           NOT NULL,
    [PromotionKey]          INT           NOT NULL,
    [CurrencyKey]           INT           NOT NULL,
    [SalesTerritoryKey]     INT           NOT NULL,
    [SalesOrderNumber]      NVARCHAR (20) NOT NULL,
    [SalesOrderLineNumber]  TINYINT       NOT NULL,
    [RevisionNumber]        TINYINT       NULL,
    [OrderQuantity]         SMALLINT      NULL,
    [UnitPrice]             MONEY         NULL,
    [ExtendedAmount]        MONEY         NULL,
    [UnitPriceDiscountPct]  FLOAT         NULL,
    [DiscountAmount]        FLOAT         NULL,
    [ProductStandardCost]   MONEY         NULL,
    [TotalProductCost]      MONEY         NULL,
    [SalesAmount]           MONEY         NULL,
    [TaxAmt]                MONEY         NULL,
    [Freight]               MONEY         NULL,
    [CarrierTrackingNumber] NVARCHAR (25) NULL,
    [CustomerPONumber]      NVARCHAR (25) NULL
)
GO
CREATE TABLE [dbo].[FactInternetSalesReason] (
    [SalesOrderNumber]     NVARCHAR (20) NOT NULL,
    [SalesOrderLineNumber] TINYINT       NOT NULL,
    [SalesReasonKey]       INT           NOT NULL
)
GO
CREATE TABLE [dbo].[FactSalesQuota] (
    [SalesQuotaKey]    INT      IDENTITY (1, 1) NOT NULL,
    [EmployeeKey]      INT      NOT NULL,
    [DateKey]          INT      NOT NULL,
    [CalendarYear]     SMALLINT NOT NULL,
    [CalendarQuarter]  TINYINT  NOT NULL,
    [SalesAmountQuota] MONEY    NOT NULL
)
GO
CREATE TABLE [dbo].[FactSurveyResponse] (
    [SurveyResponseKey]             INT           IDENTITY (1, 1) NOT NULL,
    [DateKey]                       INT           NOT NULL,
    [CustomerKey]                   INT           NOT NULL,
    [ProductCategoryKey]            INT           NOT NULL,
    [EnglishProductCategoryName]    NVARCHAR (50) NOT NULL,
    [ProductSubcategoryKey]         INT           NOT NULL,
    [EnglishProductSubcategoryName] NVARCHAR (50) NOT NULL
)
GO
CREATE TABLE [dbo].[ProspectiveBuyer] (
    [ProspectiveBuyerKey]  INT            IDENTITY (1, 1) NOT NULL,
    [ProspectAlternateKey] NVARCHAR (15)  NULL,
    [FirstName]            NVARCHAR (50)  NULL,
    [MiddleName]           NVARCHAR (50)  NULL,
    [LastName]             NVARCHAR (50)  NULL,
    [BirthDate]            DATETIME       NULL,
    [MaritalStatus]        NCHAR (1)      NULL,
    [Gender]               NVARCHAR (1)   NULL,
    [EmailAddress]         NVARCHAR (50)  NULL,
    [YearlyIncome]         MONEY          NULL,
    [TotalChildren]        TINYINT        NULL,
    [NumberChildrenAtHome] TINYINT        NULL,
    [Education]            NVARCHAR (40)  NULL,
    [Occupation]           NVARCHAR (100) NULL,
    [HouseOwnerFlag]       NCHAR (1)      NULL,
    [NumberCarsOwned]      TINYINT        NULL,
    [AddressLine1]         NVARCHAR (120) NULL,
    [AddressLine2]         NVARCHAR (120) NULL,
    [City]                 NVARCHAR (30)  NULL,
    [StateProvinceCode]    NVARCHAR (3)   NULL,
    [PostalCode]           NVARCHAR (15)  NULL,
    [Phone]                NVARCHAR (20)  NULL,
    [Salutation]           NVARCHAR (8)   NULL,
    [Unknown]              INT            NULL
)
GO
PRINT ''
GO
PRINT '*** Loading Data'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[AdventureWorksDWBuildVersion]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimAccount]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimCurrency]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimCustomer]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimDate]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimDepartmentGroup]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimEmployee]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimGeography]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimOrganization]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimProduct]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimProductCategory]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimProductSubcategory]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimPromotion]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimReseller]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimSalesReason]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimSalesTerritory]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[DimScenario]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactAdditionalInternationalProductDescription]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactCallCenter]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactFinance]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactCurrencyRate]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactInternetSalesReason]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactInternetSales]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactResellerSales]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactSalesQuota]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[FactSurveyResponse]'
GO
PRINT 'Loading [AdventureWorksDW2008R2].[dbo].[ProspectiveBuyer]'
GO
PRINT ''
GO
PRINT '*** Adding Primary Keys'
GO
ALTER TABLE [dbo].[DimAccount] WITH CHECK
    ADD CONSTRAINT [PK_DimAccount] PRIMARY KEY CLUSTERED ([AccountKey])
GO
ALTER TABLE [dbo].[DimCurrency] WITH CHECK
    ADD CONSTRAINT [PK_DimCurrency_CurrencyKey] PRIMARY KEY CLUSTERED ([CurrencyKey])
GO
ALTER TABLE [dbo].[DimCustomer] WITH CHECK
    ADD CONSTRAINT [PK_DimCustomer_CustomerKey] PRIMARY KEY CLUSTERED ([CustomerKey])
GO
ALTER TABLE [dbo].[DimDepartmentGroup] WITH CHECK
    ADD CONSTRAINT [PK_DimDepartmentGroup] PRIMARY KEY CLUSTERED ([DepartmentGroupKey])
GO
ALTER TABLE [dbo].[DimEmployee] WITH CHECK
    ADD CONSTRAINT [PK_DimEmployee_EmployeeKey] PRIMARY KEY CLUSTERED ([EmployeeKey])
GO
ALTER TABLE [dbo].[DimGeography] WITH CHECK
    ADD CONSTRAINT [PK_DimGeography_GeographyKey] PRIMARY KEY CLUSTERED ([GeographyKey])
GO
ALTER TABLE [dbo].[DimOrganization] WITH CHECK
    ADD CONSTRAINT [PK_DimOrganization] PRIMARY KEY CLUSTERED ([OrganizationKey])
GO
ALTER TABLE [dbo].[DimProduct] WITH CHECK
    ADD CONSTRAINT [PK_DimProduct_ProductKey] PRIMARY KEY CLUSTERED ([ProductKey])
GO
ALTER TABLE [dbo].[DimProductCategory] WITH CHECK
    ADD CONSTRAINT [PK_DimProductCategory_ProductCategoryKey] PRIMARY KEY CLUSTERED ([ProductCategoryKey])
GO
ALTER TABLE [dbo].[DimProductSubcategory] WITH CHECK
    ADD CONSTRAINT [PK_DimProductSubcategory_ProductSubcategoryKey] PRIMARY KEY CLUSTERED ([ProductSubcategoryKey])
GO
ALTER TABLE [dbo].[DimPromotion] WITH CHECK
    ADD CONSTRAINT [PK_DimPromotion_PromotionKey] PRIMARY KEY CLUSTERED ([PromotionKey])
GO
ALTER TABLE [dbo].[DimReseller] WITH CHECK
    ADD CONSTRAINT [PK_DimReseller_ResellerKey] PRIMARY KEY CLUSTERED ([ResellerKey])
GO
ALTER TABLE [dbo].[DimSalesReason] WITH CHECK
    ADD CONSTRAINT [PK_DimSalesReason_SalesReasonKey] PRIMARY KEY CLUSTERED ([SalesReasonKey])
GO
ALTER TABLE [dbo].[DimSalesTerritory] WITH CHECK
    ADD CONSTRAINT [PK_DimSalesTerritory_SalesTerritoryKey] PRIMARY KEY CLUSTERED ([SalesTerritoryKey])
GO
ALTER TABLE [dbo].[DimScenario] WITH CHECK
    ADD CONSTRAINT [PK_DimScenario] PRIMARY KEY CLUSTERED ([ScenarioKey])
GO
ALTER TABLE [dbo].[DimDate] WITH CHECK
    ADD CONSTRAINT [PK_DimDate_DateKey] PRIMARY KEY CLUSTERED ([DateKey])
GO
ALTER TABLE [dbo].[FactAdditionalInternationalProductDescription] WITH CHECK
    ADD CONSTRAINT [PK_FactAdditionalInternationalProductDescription_ProductKey_CultureName] PRIMARY KEY CLUSTERED ([ProductKey], [CultureName])
GO
ALTER TABLE [dbo].[FactCallCenter] WITH CHECK
    ADD CONSTRAINT [PK_FactCallCenter_FactCallCenterID] PRIMARY KEY CLUSTERED ([FactCallCenterID])
GO
ALTER TABLE [dbo].[FactCurrencyRate] WITH CHECK
    ADD CONSTRAINT [PK_FactCurrencyRate_CurrencyKey_DateKey] PRIMARY KEY CLUSTERED ([CurrencyKey], [DateKey])
GO
ALTER TABLE [dbo].[FactInternetSales]
    ADD CONSTRAINT [PK_FactInternetSales_SalesOrderNumber_SalesOrderLineNumber] PRIMARY KEY CLUSTERED ([SalesOrderNumber], [SalesOrderLineNumber])
GO
ALTER TABLE [dbo].[FactResellerSales]
    ADD CONSTRAINT [PK_FactResellerSales_SalesOrderNumber_SalesOrderLineNumber] PRIMARY KEY CLUSTERED ([SalesOrderNumber], [SalesOrderLineNumber])
GO
ALTER TABLE [dbo].[FactInternetSalesReason]
    ADD CONSTRAINT [PK_FactInternetSalesReason_SalesOrderNumber_SalesOrderLineNumber_SalesReasonKey] PRIMARY KEY CLUSTERED ([SalesOrderNumber], [SalesOrderLineNumber], [SalesReasonKey])
GO
ALTER TABLE [dbo].[FactSalesQuota]
    ADD CONSTRAINT [PK_FactSalesQuota_SalesQuotaKey] PRIMARY KEY CLUSTERED ([SalesQuotaKey])
GO
ALTER TABLE [dbo].[FactSurveyResponse]
    ADD CONSTRAINT [PK_FactSurveyResponse_SurveyResponseKey] PRIMARY KEY CLUSTERED ([SurveyResponseKey])
GO
ALTER TABLE [dbo].[ProspectiveBuyer]
    ADD CONSTRAINT [PK_ProspectiveBuyer_ProspectiveBuyerKey] PRIMARY KEY CLUSTERED ([ProspectiveBuyerKey])
GO
PRINT ''
GO
PRINT '*** Adding Indexes'
GO
CREATE UNIQUE INDEX [AK_DimAccount_AccountCodeAlternateKey]
    ON [dbo].[DimAccount]([AccountCodeAlternateKey])
GO
ALTER TABLE [dbo].[DimCurrency]
    ADD CONSTRAINT [AK_DimCurrency_CurrencyAlternateKey] UNIQUE NONCLUSTERED ([CurrencyAlternateKey])
GO
ALTER TABLE [dbo].[DimCustomer]
    ADD CONSTRAINT [IX_DimCustomer_CustomerAlternateKey] UNIQUE NONCLUSTERED ([CustomerAlternateKey])
GO
CREATE INDEX [IX_DimCustomer_GeographyKey]
    ON [dbo].[DimCustomer]([GeographyKey])
GO
CREATE INDEX [IX_DimEmployee_ParentEmployeeKey]
    ON [dbo].[DimEmployee]([ParentEmployeeKey])
GO
CREATE INDEX [IX_DimEmployee_SalesTerritoryKey]
    ON [dbo].[DimEmployee]([SalesTerritoryKey])
GO
ALTER TABLE [dbo].[DimProduct]
    ADD CONSTRAINT [AK_DimProduct_ProductAlternateKey_StartDate] UNIQUE NONCLUSTERED ([ProductAlternateKey], [StartDate])
GO
CREATE INDEX [IX_DimProduct_ProductSubcategoryKey]
    ON [dbo].[DimProduct]([ProductSubcategoryKey])
GO
ALTER TABLE [dbo].[DimProductCategory]
    ADD CONSTRAINT [AK_DimProductCategory_ProductCategoryAlternateKey] UNIQUE NONCLUSTERED ([ProductCategoryAlternateKey])
GO
ALTER TABLE [dbo].[DimProductSubcategory]
    ADD CONSTRAINT [AK_DimProductSubcategory_ProductSubcategoryAlternateKey] UNIQUE NONCLUSTERED ([ProductSubcategoryAlternateKey])
GO
ALTER TABLE [dbo].[DimPromotion]
    ADD CONSTRAINT [AK_DimPromotion_PromotionAlternateKey] UNIQUE NONCLUSTERED ([PromotionAlternateKey])
GO
ALTER TABLE [dbo].[DimReseller]
    ADD CONSTRAINT [AK_DimReseller_ResellerAlternateKey] UNIQUE NONCLUSTERED ([ResellerAlternateKey])
GO
CREATE INDEX [IX_DimReseller_GeographyKey]
    ON [dbo].[DimReseller]([GeographyKey])
GO
ALTER TABLE [dbo].[DimSalesTerritory]
    ADD CONSTRAINT [AK_DimSalesTerritory_SalesTerritoryAlternateKey] UNIQUE NONCLUSTERED ([SalesTerritoryAlternateKey])
GO
ALTER TABLE [dbo].[DimDate]
    ADD CONSTRAINT [AK_DimDate_FullDateAlternateKey] UNIQUE NONCLUSTERED ([FullDateAlternateKey])
GO
ALTER TABLE [dbo].[FactCallCenter]
    ADD CONSTRAINT [AK_FactCallCenter_DateKey_Shift] UNIQUE NONCLUSTERED ([DateKey], [Shift])
GO
CREATE INDEX [IX_FactInternetSales_CurrencyKey]
    ON [dbo].[FactInternetSales]([CurrencyKey])
GO
CREATE INDEX [IX_FactInternetSales_CustomerKey]
    ON [dbo].[FactInternetSales]([CustomerKey])
GO
CREATE INDEX [IX_FactInternetSales_DueDateKey]
    ON [dbo].[FactInternetSales]([DueDateKey])
GO
CREATE INDEX [IX_FactInternetSales_OrderDateKey]
    ON [dbo].[FactInternetSales]([OrderDateKey])
GO
CREATE INDEX [IX_FactInternetSales_ProductKey]
    ON [dbo].[FactInternetSales]([ProductKey])
GO
CREATE INDEX [IX_FactInternetSales_PromotionKey]
    ON [dbo].[FactInternetSales]([PromotionKey])
GO
CREATE INDEX [IX_FactIneternetSales_ShipDateKey]
    ON [dbo].[FactInternetSales]([ShipDateKey])
GO
CREATE INDEX [IX_FactResellerSales_CurrencyKey]
    ON [dbo].[FactResellerSales]([CurrencyKey])
GO
CREATE INDEX [IX_FactResellerSales_DueDateKey]
    ON [dbo].[FactResellerSales]([DueDateKey])
GO
CREATE INDEX [IX_FactResellerSales_OrderDateKey]
    ON [dbo].[FactResellerSales]([OrderDateKey])
GO
CREATE INDEX [IX_FactResellerSales_ProductKey]
    ON [dbo].[FactResellerSales]([ProductKey])
GO
CREATE INDEX [IX_FactResellerSales_PromotionKey]
    ON [dbo].[FactResellerSales]([PromotionKey])
GO
CREATE INDEX [IX_FactResellerSales_ShipDateKey]
    ON [dbo].[FactResellerSales]([ShipDateKey])
GO
CREATE INDEX [IX_FactResellerSales_EmployeeKey]
    ON [dbo].[FactResellerSales]([EmployeeKey])
GO
CREATE INDEX [IX_FactResellerSales_ResellerKey]
    ON [dbo].[FactResellerSales]([ResellerKey])
GO
CREATE INDEX [IX_FactSalesQuota_EmployeeKey]
    ON [dbo].[FactSalesQuota]([EmployeeKey])
GO
CREATE INDEX [IX_FactSalesQuota_DateKey]
    ON [dbo].[FactSalesQuota]([DateKey])
GO
CREATE INDEX [IX_FactSurveyResponse_DateKey]
    ON [dbo].[FactSurveyResponse]([DateKey])
GO
CREATE INDEX [IX_FactSurveyResponse_CustomerKey]
    ON [dbo].[FactSurveyResponse]([CustomerKey])
GO
CREATE INDEX [IX_FactSurveyResponse_ProductSubcategoryKey]
    ON [dbo].[FactSurveyResponse]([ProductSubcategoryKey])
GO
CREATE INDEX [IX_ProspectiveBuyer_ProspectAlternateKey]
    ON [dbo].[ProspectiveBuyer]([ProspectAlternateKey])
GO
PRINT ''
GO
PRINT '*** Creating Foreign Key Constraints'
GO
ALTER TABLE [dbo].[DatabaseLog]
    ADD CONSTRAINT [PK_DatabaseLog_DatabaseLogID] PRIMARY KEY CLUSTERED ([DatabaseLogID])
GO
ALTER TABLE [dbo].[AdventureWorksDWBuildVersion]
    ADD CONSTRAINT [PK_AdventureWorksDWBuildVersion_DBVersion_VersionDate] PRIMARY KEY CLUSTERED ([DBVersion], [VersionDate])
GO
ALTER TABLE [dbo].[FactFinance]
    ADD CONSTRAINT [PK_FactFinance_FinanceKey] PRIMARY KEY CLUSTERED ([FinanceKey])
GO
